**To delete a rule**

The following ``delete-topic-rule`` example deletes the specified rule. ::

    aws iot delete-topic-rule \
        --rule-name "LowMoistureRule"

This command produces no output.

For more information, see `Deleting a Rule <https://docs.aws.amazon.com/iot/latest/developerguide/iot-delete-rule.html>`__ in the *AWS IoT Developers Guide*.

